==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/chalk/plugins/viewplugins/performancetest/dlg_perftest.cc <==
/*
 *  dlg_perftest.cc - part of KimageShop^WKrayon^WChalk
 *
 *  Copyright (c) 2004 Michael Thaler <michael.thaler@physik.tu-muenchen.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <config.h>

#include <math.h>

#include <iostream>

using namespace std;

#include <tqradiobutton.h>
#include <tqpushbutton.h>
#include <tqcheckbox.h>
#include <tqlabel.h>

#include <klocale.h>
#include <knuminput.h>
#include <kdebug.h>

#include "dlg_perftest.h"
#include "wdg_perftest.h"


DlgPerfTest::DlgPerfTest( TQWidget *  parent,
                const char * name)
    : super (parent, name, true, i18n("Performance Test"), Ok | Cancel, Ok)
{
    m_lock = false;

    m_page = new WdgPerfTest(this, "perf_test");
    Q_CHECK_PTR(m_page);

    setMainWidget(m_page);
    resize(m_page->sizeHint());

    connect(this, TQT_SIGNAL(okClicked()),
        this, TQT_SLOT(okClicked()));

    connect(m_page->btnSelectAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectAllClicked()));
    connect(m_page->btnDeselectAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(deselectAllClicked()));
}

DlgPerfTest::~DlgPerfTest()
{
    delete m_page;
}

WdgPerfTest * DlgPerfTest::page()
{
    return m_page;
}

// SLOTS

void DlgPerfTest::okClicked()
{
    accept();
}

void DlgPerfTest::setAllTestCheckBoxes(bool checked)
{
    m_page->chkBitBlt->setChecked(checked);
    m_page->chkFill->setChecked(checked);
    m_page->chkGradient->setChecked(checked);
    m_page->chkPixel->setChecked(checked);
    m_page->chkShape->setChecked(checked);
    m_page->chkLayer->setChecked(checked);
    m_page->chkScale->setChecked(checked);
    m_page->chkRotate->setChecked(checked);
    m_page->chkRender->setChecked(checked);
    m_page->chkSelection->setChecked(checked);
    m_page->chkColorConversion->setChecked(checked);
    m_page->chkFilter->setChecked(checked);
    m_page->chkReadBytes->setChecked(checked);
    m_page->chkWriteBytes->setChecked(checked);
    m_page->chkIterators->setChecked(checked);
    m_page->chkPaintView->setChecked(checked);
    m_page->chkPaintViewFPS->setChecked(checked);
}

void DlgPerfTest::selectAllClicked()
{
    setAllTestCheckBoxes(true);
}

void DlgPerfTest::deselectAllClicked()
{
    setAllTestCheckBoxes(false);
}


#include "dlg_perftest.moc"

==> koffice-trinity-14.0.7.tar.xz: koffice-trinity-14.0.7/chalk/plugins/viewplugins/performancetest/dlg_perftest.cc <==
/*
 *  dlg_perftest.cc - part of KimageShop^WKrayon^WChalk
 *
 *  Copyright (c) 2004 Michael Thaler <michael.thaler@physik.tu-muenchen.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <config.h>

#include <math.h>

#include <iostream>

using namespace std;

#include <tqradiobutton.h>
#include <tqpushbutton.h>
#include <tqcheckbox.h>
#include <tqlabel.h>

#include <tdelocale.h>
#include <knuminput.h>
#include <kdebug.h>

#include "dlg_perftest.h"
#include "wdg_perftest.h"


DlgPerfTest::DlgPerfTest( TQWidget *  parent,
                const char * name)
    : super (parent, name, true, i18n("Performance Test"), Ok | Cancel, Ok)
{
    m_lock = false;

    m_page = new WdgPerfTest(this, "perf_test");
    TQ_CHECK_PTR(m_page);

    setMainWidget(m_page);
    resize(m_page->sizeHint());

    connect(this, TQT_SIGNAL(okClicked()),
        this, TQT_SLOT(okClicked()));

    connect(m_page->btnSelectAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectAllClicked()));
    connect(m_page->btnDeselectAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(deselectAllClicked()));
}

DlgPerfTest::~DlgPerfTest()
{
    delete m_page;
}

WdgPerfTest * DlgPerfTest::page()
{
    return m_page;
}

// SLOTS

void DlgPerfTest::okClicked()
{
    accept();
}

void DlgPerfTest::setAllTestCheckBoxes(bool checked)
{
    m_page->chkBitBlt->setChecked(checked);
    m_page->chkFill->setChecked(checked);
    m_page->chkGradient->setChecked(checked);
    m_page->chkPixel->setChecked(checked);
    m_page->chkShape->setChecked(checked);
    m_page->chkLayer->setChecked(checked);
    m_page->chkScale->setChecked(checked);
    m_page->chkRotate->setChecked(checked);
    m_page->chkRender->setChecked(checked);
    m_page->chkSelection->setChecked(checked);
    m_page->chkColorConversion->setChecked(checked);
    m_page->chkFilter->setChecked(checked);
    m_page->chkReadBytes->setChecked(checked);
    m_page->chkWriteBytes->setChecked(checked);
    m_page->chkIterators->setChecked(checked);
    m_page->chkPaintView->setChecked(checked);
    m_page->chkPaintViewFPS->setChecked(checked);
}

void DlgPerfTest::selectAllClicked()
{
    setAllTestCheckBoxes(true);
}

void DlgPerfTest::deselectAllClicked()
{
    setAllTestCheckBoxes(false);
}


#include "dlg_perftest.moc"
